mailr15850 - /1.3/prompt/bruker.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 30, 2012 - 14:42:
Author: bugman
Date: Mon Apr 30 12:48:28 2012
New Revision: 15850

URL: http://svn.gna.org/viewcvs/relax?rev=15850&view=rev
Log:
Converted the bruker.read user function prompt interface to the new design.

This will be required for implementation in the GUI.


Modified:
    1.3/prompt/bruker.py

Modified: 1.3/prompt/bruker.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/prompt/bruker.py?rev=15850&r1=15849&r2=15850&view=diff
==============================================================================
--- 1.3/prompt/bruker.py (original)
+++ 1.3/prompt/bruker.py Mon Apr 30 12:48:28 2012
@@ -21,38 +21,19 @@
 
###############################################################################
 
 # Module docstring.
 """Module containing the Bruker Dynamics Centre user function class."""
 __docformat__ = 'plaintext'
 
 # relax module imports.
 import arg_check
-from base_class import User_fn_class
+from base_class import User_fn_class, _build_doc
 from generic_fns import bruker
 
 
 class Bruker(User_fn_class):
-    """Class containing the function for reading the Bruker Dynamics Centre 
(DC) files."""
+    """Class containing the function for reading the Bruker Dynamics Center 
(DC) files."""
 
     def read(self, ri_id=None, file=None, dir=None):
-        """Read the Bruker Dynamics Centre (DC) file.
-
-        Keyword Arguments
-        ~~~~~~~~~~~~~~~~~
-
-        ri_id:  The relaxation data ID string.
-
-        file:  The name of the DC file.
-
-        dir:  The directory where the file is located.
-
-
-        Description
-        ~~~~~~~~~~~
-
-        This user function is used to load all of the data out of a Bruker 
DC file for subsequent
-        analysis within relax.
-        """
-
         # Function intro text.
         if self._exec_info.intro:
             text = self._exec_info.ps3 + "bruker.read("
@@ -68,3 +49,18 @@
 
         # Execute the functional code.
         bruker.read(ri_id=ri_id, file=file, dir=dir)
+
+    # The function doc info.
+    read._doc_title = "Read a Bruker Dynamics Center (DC) file."
+    read._doc_title_short = "Reading a Bruker Dynamics Center file."
+    read._doc_args = [
+        ["ri_id", "The relaxation data ID string.  This must be a unique 
identifier."],
+        ["file", "The name of the Bruker Dynamics Center file containing the 
relaxation data."],
+        ["dir", "The directory where the file is located."],
+    ]
+    read._doc_desc = """
+        This user function is used to load all of the data out of a Bruker 
Dynamics Center (DC) file for subsequent analysis within relax.
+        """
+    _build_doc(read)
+
+
@@ -21,38 +21,19 @@
 
 # Module docstring.
-"""Module containing the Bruker Dynamics Centre user function class."""
+"""Module containing the Bruker Dynamics Center user function class."""
 __docformat__ = 'plaintext'
 




Related Messages


Powered by MHonArc, Updated Mon Apr 30 15:00:06 2012